==> cdktf-cdktf-provider-google-0.5.135.tar.gz: package/lib/kms-crypto-key.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KmsCryptoKeyConfig extends cdktf.TerraformMetaArguments {
    /**
     * The period of time that versions of this key spend in the DESTROY_SCHEDULED state before transitioning to DESTROYED.
     *
     * If not specified at creation time, the default duration is 24 hours.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#destroy_scheduled_duration KmsCryptoKey#destroy_scheduled_duration}
     *
     * @stability stable
     */
    readonly destroyScheduledDuration?: string;
    /**
     * Whether this key may contain imported versions only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#import_only KmsCryptoKey#import_only}
     *
     * @stability stable
     */
    readonly importOnly?: boolean | cdktf.IResolvable;
    /**
     * The KeyRing that this key belongs to. Format: ''projects/{{project}}/locations/{{location}}/keyRings/{{keyRing}}''.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#key_ring KmsCryptoKey#key_ring}
     *
     * @stability stable
     */
    readonly keyRing: string;
    /**
     * Labels with user-defined metadata to apply to this resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#labels KmsCryptoKey#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * The resource name for the CryptoKey.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#name KmsCryptoKey#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The immutable purpose of this CryptoKey. See the [purpose reference](https://cloud.google.com/kms/docs/reference/rest/v1/projects.locations.keyRings.cryptoKeys#CryptoKeyPurpose) for possible inputs. Default value: "ENCRYPT_DECRYPT" Possible values: ["ENCRYPT_DECRYPT", "ASYMMETRIC_SIGN", "ASYMMETRIC_DECRYPT"].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#purpose KmsCryptoKey#purpose}
     *
     * @stability stable
     */
    readonly purpose?: string;
    /**
     * Every time this period passes, generate a new CryptoKeyVersion and set it as the primary.
     *
     * The first rotation will take place after the specified period. The rotation period has
     * the format of a decimal number with up to 9 fractional digits, followed by the
     * letter 's' (seconds). It must be greater than a day (ie, 86400).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#rotation_period KmsCryptoKey#rotation_period}
     *
     * @stability stable
     */
    readonly rotationPeriod?: string;
    /**
     * If set to true, the request will create a CryptoKey without any CryptoKeyVersions.
     *
     * You must use the 'google_kms_key_ring_import_job' resource to import the CryptoKeyVersion.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#skip_initial_version_creation KmsCryptoKey#skip_initial_version_creation}
     *
     * @stability stable
     */
    readonly skipInitialVersionCreation?: boolean | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#timeouts KmsCryptoKey#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: KmsCryptoKeyTimeouts;
    /**
     * version_template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#version_template KmsCryptoKey#version_template}
     *
     * @stability stable
     */
    readonly versionTemplate?: KmsCryptoKeyVersionTemplate;
}
/**
 * @stability stable
 */
export interface KmsCryptoKeyTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#create KmsCryptoKey#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#delete KmsCryptoKey#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#update KmsCryptoKey#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function kmsCryptoKeyTimeoutsToTerraform(struct?: KmsCryptoKeyTimeoutsOutputReference | KmsCryptoKeyTimeouts): any;
/**
 * @stability stable
 */
export declare class KmsCryptoKeyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): KmsCryptoKeyTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: KmsCryptoKeyTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface KmsCryptoKeyVersionTemplate {
    /**
     * The algorithm to use when creating a version based on this template. See the [algorithm reference](https://cloud.google.com/kms/docs/reference/rest/v1/CryptoKeyVersionAlgorithm) for possible inputs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#algorithm KmsCryptoKey#algorithm}
     *
     * @stability stable
     */
    readonly algorithm: string;
    /**
     * The protection level to use when creating a version based on this template.
     *
     * Default value: "SOFTWARE" Possible values: ["SOFTWARE", "HSM"]
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#protection_level KmsCryptoKey#protection_level}
     *
     * @stability stable
     */
    readonly protectionLevel?: string;
}
export declare function kmsCryptoKeyVersionTemplateToTerraform(struct?: KmsCryptoKeyVersionTemplateOutputReference | KmsCryptoKeyVersionTemplate): any;
/**
 * @stability stable
 */
export declare class KmsCryptoKeyVersionTemplateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): KmsCryptoKeyVersionTemplate | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: KmsCryptoKeyVersionTemplate | undefined);
    private _algorithm?;
    /**
     * @stability stable
     */
    get algorithm(): string;
    /**
     * @stability stable
     */
    set algorithm(value: string);
    /**
     * @stability stable
     */
    get algorithmInput(): string | undefined;
    private _protectionLevel?;
    /**
     * @stability stable
     */
    get protectionLevel(): string;
    /**
     * @stability stable
     */
    set protectionLevel(value: string);
    /**
     * @stability stable
     */
    resetProtectionLevel(): void;
    /**
     * @stability stable
     */
    get protectionLevelInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key google_kms_crypto_key}.
 *
 * @stability stable
 */
export declare class KmsCryptoKey extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key google_kms_crypto_key} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KmsCryptoKeyConfig);
    private _destroyScheduledDuration?;
    /**
     * @stability stable
     */
    get destroyScheduledDuration(): string;
    /**
     * @stability stable
     */
    set destroyScheduledDuration(value: string);
    /**
     * @stability stable
     */
    resetDestroyScheduledDuration(): void;
    /**
     * @stability stable
     */
    get destroyScheduledDurationInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _importOnly?;
    /**
     * @stability stable
     */
    get importOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set importOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetImportOnly(): void;
    /**
     * @stability stable
     */
    get importOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _keyRing?;
    /**
     * @stability stable
     */
    get keyRing(): string;
    /**
     * @stability stable
     */
    set keyRing(value: string);
    /**
     * @stability stable
     */
    get keyRingInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _purpose?;
    /**
     * @stability stable
     */
    get purpose(): string;
    /**
     * @stability stable
     */
    set purpose(value: string);
    /**
     * @stability stable
     */
    resetPurpose(): void;
    /**
     * @stability stable
     */
    get purposeInput(): string | undefined;
    private _rotationPeriod?;
    /**
     * @stability stable
     */
    get rotationPeriod(): string;
    /**
     * @stability stable
     */
    set rotationPeriod(value: string);
    /**
     * @stability stable
     */
    resetRotationPeriod(): void;
    /**
     * @stability stable
     */
    get rotationPeriodInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _skipInitialVersionCreation?;
    /**
     * @stability stable
     */
    get skipInitialVersionCreation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set skipInitialVersionCreation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSkipInitialVersionCreation(): void;
    /**
     * @stability stable
     */
    get skipInitialVersionCreationInput(): boolean | cdktf.IResolvable | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): KmsCryptoKeyTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: KmsCryptoKeyTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): KmsCryptoKeyTimeouts | undefined;
    private _versionTemplate;
    /**
     * @stability stable
     */
    get versionTemplate(): KmsCryptoKeyVersionTemplateOutputReference;
    /**
     * @stability stable
     */
    putVersionTemplate(value: KmsCryptoKeyVersionTemplate): void;
    /**
     * @stability stable
     */
    resetVersionTemplate(): void;
    /**
     * @stability stable
     */
    get versionTemplateInput(): KmsCryptoKeyVersionTemplate | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.1.tar.gz: package/lib/kms-crypto-key.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KmsCryptoKeyConfig extends cdktf.TerraformMetaArguments {
    /**
     * The period of time that versions of this key spend in the DESTROY_SCHEDULED state before transitioning to DESTROYED.
     *
     * If not specified at creation time, the default duration is 24 hours.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#destroy_scheduled_duration KmsCryptoKey#destroy_scheduled_duration}
     *
     * @stability stable
     */
    readonly destroyScheduledDuration?: string;
    /**
     * Whether this key may contain imported versions only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#import_only KmsCryptoKey#import_only}
     *
     * @stability stable
     */
    readonly importOnly?: boolean | cdktf.IResolvable;
    /**
     * The KeyRing that this key belongs to. Format: ''projects/{{project}}/locations/{{location}}/keyRings/{{keyRing}}''.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#key_ring KmsCryptoKey#key_ring}
     *
     * @stability stable
     */
    readonly keyRing: string;
    /**
     * Labels with user-defined metadata to apply to this resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#labels KmsCryptoKey#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The resource name for the CryptoKey.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#name KmsCryptoKey#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The immutable purpose of this CryptoKey. See the [purpose reference](https://cloud.google.com/kms/docs/reference/rest/v1/projects.locations.keyRings.cryptoKeys#CryptoKeyPurpose) for possible inputs. Default value: "ENCRYPT_DECRYPT" Possible values: ["ENCRYPT_DECRYPT", "ASYMMETRIC_SIGN", "ASYMMETRIC_DECRYPT"].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#purpose KmsCryptoKey#purpose}
     *
     * @stability stable
     */
    readonly purpose?: string;
    /**
     * Every time this period passes, generate a new CryptoKeyVersion and set it as the primary.
     *
     * The first rotation will take place after the specified period. The rotation period has
     * the format of a decimal number with up to 9 fractional digits, followed by the
     * letter 's' (seconds). It must be greater than a day (ie, 86400).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#rotation_period KmsCryptoKey#rotation_period}
     *
     * @stability stable
     */
    readonly rotationPeriod?: string;
    /**
     * If set to true, the request will create a CryptoKey without any CryptoKeyVersions.
     *
     * You must use the 'google_kms_key_ring_import_job' resource to import the CryptoKeyVersion.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#skip_initial_version_creation KmsCryptoKey#skip_initial_version_creation}
     *
     * @stability stable
     */
    readonly skipInitialVersionCreation?: boolean | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#timeouts KmsCryptoKey#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: KmsCryptoKeyTimeouts;
    /**
     * version_template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#version_template KmsCryptoKey#version_template}
     *
     * @stability stable
     */
    readonly versionTemplate?: KmsCryptoKeyVersionTemplate;
}
/**
 * @stability stable
 */
export interface KmsCryptoKeyTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#create KmsCryptoKey#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#delete KmsCryptoKey#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#update KmsCryptoKey#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function kmsCryptoKeyTimeoutsToTerraform(struct?: KmsCryptoKeyTimeoutsOutputReference | KmsCryptoKeyTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class KmsCryptoKeyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): KmsCryptoKeyTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: KmsCryptoKeyTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface KmsCryptoKeyVersionTemplate {
    /**
     * The algorithm to use when creating a version based on this template. See the [algorithm reference](https://cloud.google.com/kms/docs/reference/rest/v1/CryptoKeyVersionAlgorithm) for possible inputs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#algorithm KmsCryptoKey#algorithm}
     *
     * @stability stable
     */
    readonly algorithm: string;
    /**
     * The protection level to use when creating a version based on this template.
     *
     * Default value: "SOFTWARE" Possible values: ["SOFTWARE", "HSM"]
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key#protection_level KmsCryptoKey#protection_level}
     *
     * @stability stable
     */
    readonly protectionLevel?: string;
}
export declare function kmsCryptoKeyVersionTemplateToTerraform(struct?: KmsCryptoKeyVersionTemplateOutputReference | KmsCryptoKeyVersionTemplate): any;
/**
 * @stability stable
 */
export declare class KmsCryptoKeyVersionTemplateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): KmsCryptoKeyVersionTemplate | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: KmsCryptoKeyVersionTemplate | undefined);
    private _algorithm?;
    /**
     * @stability stable
     */
    get algorithm(): string;
    /**
     * @stability stable
     */
    set algorithm(value: string);
    /**
     * @stability stable
     */
    get algorithmInput(): string | undefined;
    private _protectionLevel?;
    /**
     * @stability stable
     */
    get protectionLevel(): string;
    /**
     * @stability stable
     */
    set protectionLevel(value: string);
    /**
     * @stability stable
     */
    resetProtectionLevel(): void;
    /**
     * @stability stable
     */
    get protectionLevelInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key google_kms_crypto_key}.
 *
 * @stability stable
 */
export declare class KmsCryptoKey extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/kms_crypto_key google_kms_crypto_key} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KmsCryptoKeyConfig);
    private _destroyScheduledDuration?;
    /**
     * @stability stable
     */
    get destroyScheduledDuration(): string;
    /**
     * @stability stable
     */
    set destroyScheduledDuration(value: string);
    /**
     * @stability stable
     */
    resetDestroyScheduledDuration(): void;
    /**
     * @stability stable
     */
    get destroyScheduledDurationInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _importOnly?;
    /**
     * @stability stable
     */
    get importOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set importOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetImportOnly(): void;
    /**
     * @stability stable
     */
    get importOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _keyRing?;
    /**
     * @stability stable
     */
    get keyRing(): string;
    /**
     * @stability stable
     */
    set keyRing(value: string);
    /**
     * @stability stable
     */
    get keyRingInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _purpose?;
    /**
     * @stability stable
     */
    get purpose(): string;
    /**
     * @stability stable
     */
    set purpose(value: string);
    /**
     * @stability stable
     */
    resetPurpose(): void;
    /**
     * @stability stable
     */
    get purposeInput(): string | undefined;
    private _rotationPeriod?;
    /**
     * @stability stable
     */
    get rotationPeriod(): string;
    /**
     * @stability stable
     */
    set rotationPeriod(value: string);
    /**
     * @stability stable
     */
    resetRotationPeriod(): void;
    /**
     * @stability stable
     */
    get rotationPeriodInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _skipInitialVersionCreation?;
    /**
     * @stability stable
     */
    get skipInitialVersionCreation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set skipInitialVersionCreation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSkipInitialVersionCreation(): void;
    /**
     * @stability stable
     */
    get skipInitialVersionCreationInput(): boolean | cdktf.IResolvable | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): KmsCryptoKeyTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: KmsCryptoKeyTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): KmsCryptoKeyTimeouts | undefined;
    private _versionTemplate;
    /**
     * @stability stable
     */
    get versionTemplate(): KmsCryptoKeyVersionTemplateOutputReference;
    /**
     * @stability stable
     */
    putVersionTemplate(value: KmsCryptoKeyVersionTemplate): void;
    /**
     * @stability stable
     */
    resetVersionTemplate(): void;
    /**
     * @stability stable
     */
    get versionTemplateInput(): KmsCryptoKeyVersionTemplate | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
